#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// Welles Wilder's Moving Average
    /// </summary>
    [Description("Welles Wilder's Moving Average")]
    public class WWMA : Indicator
    {
        #region Variables
		private int period = 14;
        #endregion

        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
			Add(new Plot(Color.Orange, "WWMA"));
            Overlay				= true;
            PriceTypeSupported	= true;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {			
			Value.Set(CurrentBar == 0 ? Input[0] : (Value[1] * (Period - 1) + Input[0]) / Period);
        }

        #region Properties
        [Description("")]
        [Category("Parameters")]
        public int Period
        {
            get { return period; }
            set { period = Math.Max(1, value); }
        }
        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private WWMA[] cacheWWMA = null;

        private static WWMA checkWWMA = new WWMA();

        /// <summary>
        /// Welles Wilder's Moving Average
        /// </summary>
        /// <returns></returns>
        public WWMA WWMA(int period)
        {
            return WWMA(Input, period);
        }

        /// <summary>
        /// Welles Wilder's Moving Average
        /// </summary>
        /// <returns></returns>
        public WWMA WWMA(Data.IDataSeries input, int period)
        {
            checkWWMA.Period = period;
            period = checkWWMA.Period;

            if (cacheWWMA != null)
                for (int idx = 0; idx < cacheWWMA.Length; idx++)
                    if (cacheWWMA[idx].Period == period && cacheWWMA[idx].EqualsInput(input))
                        return cacheWWMA[idx];

            WWMA indicator = new WWMA();
            indicator.BarsRequired = BarsRequired;
            indicator.CalculateOnBarClose = CalculateOnBarClose;
            indicator.Input = input;
            indicator.Period = period;
            indicator.SetUp();

            WWMA[] tmp = new WWMA[cacheWWMA == null ? 1 : cacheWWMA.Length + 1];
            if (cacheWWMA != null)
                cacheWWMA.CopyTo(tmp, 0);
            tmp[tmp.Length - 1] = indicator;
            cacheWWMA = tmp;
            Indicators.Add(indicator);

            return indicator;
        }

    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// Welles Wilder's Moving Average
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.WWMA WWMA(int period)
        {
            return _indicator.WWMA(Input, period);
        }

        /// <summary>
        /// Welles Wilder's Moving Average
        /// </summary>
        /// <returns></returns>
        public Indicator.WWMA WWMA(Data.IDataSeries input, int period)
        {
            return _indicator.WWMA(input, period);
        }

    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// Welles Wilder's Moving Average
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.WWMA WWMA(int period)
        {
            return _indicator.WWMA(Input, period);
        }

        /// <summary>
        /// Welles Wilder's Moving Average
        /// </summary>
        /// <returns></returns>
        public Indicator.WWMA WWMA(Data.IDataSeries input, int period)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.WWMA(input, period);
        }

    }
}
#endregion
